# IHAN Client

IHAN Client for feeding and back filling log files

[![Build Status](https://travis-ci.org/marklit/ihan.svg?branch=master)](https://travis-ci.org/marklit/whois)
[![Coverage Status](https://coveralls.io/repos/marklit/ihan/badge.png)](https://coveralls.io/r/marklit/whois)
[![license](http://img.shields.io/badge/license-MIT-red.svg?style=flat)](http://opensource.org/licenses/MIT)